#
# spec file for package crow-translate
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2019, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define  _name  io.crow_translate.CrowTranslate
Name:           crow-translate
Version:        2.10.0
Release:        bp156.2.11
Summary:        A Qt GUI for Google, Yandex and Bing translators
License:        GPL-3.0-only
Group:          Productivity/Networking/Web/Frontends
URL:            https://crow-translate.github.io/
Source0:        https://github.com/%{name}/%{name}/releases/download/%{version}/%{name}-%{version}-source.tar.gz
Patch0:         third-party-library-static.patch
Patch1:         cmakelists-txt.patch
Patch2:         desktop-file.patch
BuildRequires:  cmake >= 3.16.0
BuildRequires:  extra-cmake-modules
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(lept)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(tesseract) >= 4.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
Requires:       gstreamer-plugins-good

%description
A simple and lightweight translator that allows to translate and speak
text using Google, Yandex and Bing written with Qt5.

%lang_package

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install
%suse_update_desktop_file -r %{_name} Office Dictionary

%find_lang %{name} --with-qt

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{_name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%{_datadir}/icons/hicolor/*/status/%{name}-tray-*.??g
%{_datadir}/metainfo/%{_name}.metainfo.xml

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{name}
%dir %{_datadir}/%{name}/%{name}/translations

%changelog
* Wed Sep 14 2022 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.10.0
- Remove:
  * Fluent-icon-theme-2021-08-15.tar.gz
  * QHotkey-1.4.2.tar.gz
  * QOnlineTranslator-1.5.2.tar.gz
  * QTaskbarControl-2.0.2.tar.gz
  * SingleApplication-3.2.0.tar.gz
  * circle-flags-2.3.0.tar.gz
  * fetchcontent.patch
  * Fix-install-path.patch
- Add patch:
  * third-party-library-static.patch
  * cmakelists-txt.patch
  * desktop-file.patch
* Sat Dec 25 2021 Martin Hauke <mardnh@gmx.de>
- Remove superfluous _service file
- Add patch:
  * fetchcontent.patch (handle bundled dependencies)
* Fri Dec 24 2021 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.9.1
  * Fix actions versions
  * Bump version to 2.9.1
  * Add LibreTranslate and Lingva to popup window
  * Skip app executable for release upload
  * Specify only major action versions
  * Update Italian localization from Crowdin
  * Update Finnish localization from Crowdin
  * Update Finnish localization from Crowdin
  * Update Hungarian localization from Crowdin
  * Update Turkish localization from Crowdin
* Tue Sep  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.1
  Added
  * Uyghur localization.
  * Google: Kinyarwanda, Oriya, Tatar, Turkmen and Uyghur languages.
  Changed
  * All GUI slots now available via D-Bus.
  * Fix saving selected languages.
- Update to version 2.5.0
  Added
  * Add the ability to display only language code on buttons.
  Changed
  * Fix crash at startup with specified languages for Qt < 5.14.
  * Fix Yandex SID parsing.
  * Fix paths in configuration (some settings will be lost).
* Sat Jul  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.1
  * Do not reset languages after reloading settings.
  * Fix duplicated default swap shortcut.
  * Improve global shortcuts error logging.
  * Linux: Fix .desktop file name.
* Tue Jun 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.0
  Added
  * --brief option to print only translations.
  * The ability to add, remove or reorder used languages.
  * Swap languages shortcut.
  Changed
  * Use https instead of http for all engines.
  * --audio-only option now only plays text.
  * Automatic translation disabled by default.
- Add patch:
  * Fix-install-path.patch
- Switch from qmake to cmake
* Sun May 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.2
  Added
  * The ability to exit the application via D-Bus.
  Changed
  * Return exit code 1 on translation error in CLI.
  * Fix showing the main window if it was minimized.
  * Bing: Fix language auto detection.
* Sun Jan 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.1
  Added
  * Malay localization.
  Changed
  * Fix disabling transliteration.
  * Minor performance improvements.
  * Fix Malay language flag icon.
  * Force disable embedded global shortcuts on Wayland.
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.0
  Added
  * The ability to disable embedded global shortcuts.
  * D-Bus API.
  * KDE shortcuts support.
  * The ability to simplify source text in query.
  Changed
  * Fix crash on Wayland (still no support for hotkeys and
    selection).
  * Use a simpler and more compatible way to show notifications.
  * Stop speaking source text on change.
  * Google: Fix parsing several sentences in some cases.
  * Google: Fix disabling examples.
  Removed
  * The ability to specify buttons style as useless.
* Sun Nov 24 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.2.3
